@@ -21,6 +21,8 @@ limitations under the License.
 from __future__ import annotations
 
 import asyncio
+from dataclasses import asdict
+import inspect
 from logging import Logger
 import os
 import sys
@@ -28,13 +30,12 @@ import re
 from abc import ABC
 from collections import OrderedDict
 from copy import deepcopy
-from dataclasses import dataclass
 from datetime import datetime
-from enum import Enum
 from telnetlib import Telnet
 import socket
 from typing import (
     TYPE_CHECKING,
+    Iterable,
     List,
     Optional,
     Dict,
@@ -50,7 +51,7 @@ from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from apscheduler.triggers.cron import CronTrigger
 from apscheduler.triggers.interval import IntervalTrigger
 from apscheduler.jobstores.sqlalchemy import SQLAlchemyJobStore
-from quart import Quart
+from quart import Quart, request, send_file, Response
 from quart_cors import cors
 
 from wechaty_puppet import (
@@ -62,6 +63,19 @@ from wechaty_puppet import (
     ScanStatus
 )
 
+from wechaty.schema import (
+    NavDTO,
+    NavMetadata,
+    PluginStatus,
+    StaticFileCacher,
+    WechatyPluginOptions,
+    WechatySchedulerOptions,
+    success,
+    error
+)
+from wechaty.types import EndPoint
+from wechaty.utils import WechatySetting
+
 from .config import config
 
 from .exceptions import (
@@ -124,7 +138,8 @@ def _list_routes_txt(app: Quart) -> List[str]:
     rules = list(sorted(rules, key=lambda rule: rule.endpoint))
 
     headers = ("Endpoint", "Methods", "Websocket", "Rule")
-    rule_methods = [", ".join(sorted(rule.methods)) for rule in rules if rule.methods]
+    rule_methods = [", ".join(sorted(rule.methods))
+                    for rule in rules if rule.methods]
 
     widths = [
         max(len(rule.endpoint) for rule in rules),
@@ -132,7 +147,8 @@ def _list_routes_txt(app: Quart) -> List[str]:
         len("Websocket"),
         max(len(rule.rule) for rule in rules),
     ]
-    widths = [max(len(header), width) for header, width in zip(headers, widths)]
+    widths = [max(len(header), width)
+              for header, width in zip(headers, widths)]
 
     # pylint: disable=C0209
     row = "{{0:<{0}}} | {{1:<{1}}} | {{2:<{2}}} | {{3:<{3}}}".format(*widths)
@@ -143,7 +159,8 @@ def _list_routes_txt(app: Quart) -> List[str]:
 
     for rule, methods in zip(rules, rule_methods):
         routes_txt.append(
-            row.format(rule.endpoint, methods, str(rule.websocket), rule.rule).rstrip()
+            row.format(rule.endpoint, methods, str(
+                rule.websocket), rule.rule).rstrip()
         )
     return routes_txt
 
@@ -160,7 +177,8 @@ async def get_shutdown_trigger() -> Callable[[], Coroutine[Any, Any, Any]]:
     for signal_name in ["SIGINT", "SIGTERM", "SIGBREAK"]:
         if hasattr(signal, signal_name):
             try:
-                loop.add_signal_handler(getattr(signal, signal_name), _signal_handler)
+                loop.add_signal_handler(
+                    getattr(signal, signal_name), _signal_handler)
             except NotImplementedError:
                 # Add signal handler may not be implemented on Windows
                 signal.signal(getattr(signal, signal_name), _signal_handler)
@@ -174,26 +192,6 @@ async def shutdown(trigger: Callable[[], Coroutine[Any, Any, Any]]) -> None:
     sys.exit(0)
 
 
-@dataclass
-class WechatyPluginOptions:
-    """options for wechaty plugin"""
-    name: Optional[str] = None
-    metadata: Optional[dict] = None
-
-
-@dataclass
-class WechatySchedulerOptions:
-    """options for wechaty scheduler"""
-    job_store: Union[str, SQLAlchemyJobStore] = f'sqlite:///{config.cache_dir}/job.db'
-    job_store_alias: str = 'wechaty-scheduler'
-
-
-class PluginStatus(Enum):
-    """plugin running status"""
-    Running = 0
-    Stopped = 1
-
-
 class WechatySchedulerMixin:
     """scheduler mixin for wechaty
     """
@@ -387,6 +385,13 @@ class WechatyPlugin(ABC, WechatySchedulerMixin, WechatyEventMixin):
 
     listen events from
     """
+    AUTHOR = "wechaty"
+    AVATAR = 'https://avatars.githubusercontent.com/u/10242208?v=4'
+    AUTHOR_LINK = "https://github.com/wj-Mcat"
+    ICON = "https://wechaty.js.org/img/wechaty-icon.svg"
+    VISIABLE = True
+    VIEW_URL = None
+    UI_DIR = None
 
     def __init__(self, options: Optional[WechatyPluginOptions] = None):
         self.output: Dict[str, Any] = {}
@@ -397,6 +402,64 @@ class WechatyPlugin(ABC, WechatySchedulerMixin, WechatyEventMixin):
         self._default_logger: Optional[Logger] = None
         self._cache_dir: Optional[str] = None
 
+        self.setting_file: str = os.path.join(self.cache_dir, 'setting.json')
+        self._setting_wechaty_setting: WechatySetting = WechatySetting(self.setting_file)
+
+    def metadata(self) -> NavMetadata:
+        """get the default nav metadata
+
+        Returns:
+            NavMetadata: the instance of metadata
+        """
+        return NavMetadata(
+            author=self.AUTHOR,
+            author_link=self.AUTHOR_LINK,
+            icon=self.ICON,
+            avatar=self.AVATAR,
+            view_url=self.VIEW_URL
+        )
+
+    @property
+    def setting(self) -> WechatySetting:
+        """get the setting of a plugin"""
+        return self._setting_wechaty_setting
+
+    @setting.setter
+    def setting(self, value: dict) -> None:
+        """update setting with value
+
+        Args:
+            value (dict): the value of setting dict
+        """
+        self._setting_wechaty_setting.save_setting(value)
+
+    def get_ui_dir(self) -> Optional[str]:
+        """get the ui asset dir
+        """
+        # 1. get the customized ui dir according to the static UI_DIR attribute
+        if self.UI_DIR:
+            if os.path.exists(self.UI_DIR):
+                self.logger.info(
+                    "finding the UI_DIR<%s> for plugin<%s>", self.UI_DIR, type(self))
+                return self.UI_DIR
+
+        # 2. get the default uidir: ui/dist
+        plugin_dir_path = inspect.getsourcefile(self.__class__)
+        if plugin_dir_path is None:
+            return None
+        plugin_dir = os.path.dirname(str(plugin_dir_path))
+        ui_dir = os.path.join(plugin_dir, 'ui')
+        if os.path.exists(ui_dir):
+            self.logger.info(
+                "finding the UI_DIR<%s> for plugin<%s>", ui_dir, type(self))
+            return ui_dir
+
+        self.logger.warning(
+            'the registered UI_DIR<%s> not exist, so to fetch default ui dir',
+            self.UI_DIR
+        )
+        return None
+
     def set_bot(self, bot: Wechaty) -> None:
         """set bot instance to WechatyPlugin
 
@@ -502,25 +565,14 @@ class WechatyPlugin(ABC, WechatySchedulerMixin, WechatyEventMixin):
         """hook the plugin event when active"""
 
 
-PluginTree = Dict[str, Union[str, List[str]]]
-EndPoint = Tuple[str, int]
-
-
-def _load_default_plugins() -> List[WechatyPlugin]:
-    """
-    load the system default plugins to enable more default features
-    Returns:
-    """
-    # TODO: to be implemented
-
-
-class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pylint: disable=too-many-instance-attributes
+class WechatyPluginManager:     # pylint: disable=too-many-instance-attributes
     """manage the wechaty plugin, It will support some features."""
 
     def __init__(
         self, wechaty: Wechaty,
         endpoint: EndPoint,
-        scheduler_options: Optional[Union[AsyncIOScheduler, WechatySchedulerOptions]] = None
+        scheduler_options: Optional[Union[AsyncIOScheduler,
+                                          WechatySchedulerOptions]] = None
     ):
         self._plugins: Dict[str, WechatyPlugin] = OrderedDict()
         self._wechaty: Wechaty = wechaty
@@ -537,11 +589,103 @@ class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pyli
             scheduler = AsyncIOScheduler()
 
             if isinstance(scheduler_options.job_store, str):
-                scheduler_options.job_store = SQLAlchemyJobStore(scheduler_options.job_store)
+                scheduler_options.job_store = SQLAlchemyJobStore(
+                    scheduler_options.job_store)
 
-            scheduler.add_jobstore(scheduler_options.job_store, scheduler_options.job_store_alias)
+            scheduler.add_jobstore(
+                scheduler_options.job_store, scheduler_options.job_store_alias)
         self.scheduler: AsyncIOScheduler = scheduler
 
+        self.static_file_cacher = StaticFileCacher([
+            os.path.join(os.path.dirname(__file__), 'ui')
+        ])
+
+    async def register_ui_view(self, app: Quart) -> None:
+        """register the system ui view"""
+        @app.route('/')
+        async def wechaty_ui_home_page() -> Response:
+            """home page of wechaty ui"""
+            response = await send_file(
+                os.path.join(
+                    os.path.dirname(__file__),
+                    'ui',
+                    'index.html'
+                )
+            )
+            return response
+
+        @app.route('/plugins/list')
+        async def get_plugins_nav() -> Response:
+
+            navs = []
+            for plugin in self.plugins():
+                if not plugin.VISIABLE:
+                    continue
+
+                nav = NavDTO(
+                    name=plugin.name,
+                    status=int(
+                        self._plugin_status[plugin.name] == PluginStatus.Running
+                    ))
+                nav.update_metadata(plugin.metadata())
+                navs.append(asdict(nav))
+            return success(navs)
+
+        @app.route('/plugins/status', methods=["POST", 'PUT'])
+        async def change_status() -> Response:
+            data = await request.get_json()
+            name = data.get('plugin_name', None)
+            status = data.get('status', None)
+            if name is None or status is None:
+                return error('the plugin_name and status field is required ...')
+            status = int(status)
+            if status == 0:
+                await self.stop_plugin(name)
+            elif status == 1:
+                await self.start_plugin(name)
+            else:
+                return error("unexpected plugin status, which should be one of<Stopped, Running>")
+            return success('changes success ...')
+
+        @app.route('/plugins/setting', methods=['GET'])
+        async def get_plugin_setting() -> Response:
+            name = request.args.get('plugin_name', None)
+            if name is None:
+                return error('plugin_name field is required')
+
+            if name not in self._plugins:
+                return error(f'plugin<{name}> not exist ...')
+            plugin: WechatyPlugin = self._plugins[name]
+
+            return success(plugin.setting.to_dict())
+
+        @app.route('/plugins/setting', methods=['POST', 'PUT'])
+        async def update_plugin_setting() -> Response:
+            data: dict = await request.get_json()
+            if 'setting' not in data:
+                return error("setting field is required ...")
+
+            name = data.get('plugin_name', None)
+            if not name:
+                return error("plugin_name field is required ...")
+
+            if name not in self._plugins:
+                return error(f'plugin<{name}> not exist ...')
+
+            plugin: WechatyPlugin = self._plugins[name]
+            plugin.setting = data['setting']
+            return success(None)
+
+        @app.route("/js/<string:name>", methods=['GET'])
+        @app.route("/css/<string:name>", methods=['GET'])
+        @app.route("/img/<string:name>", methods=['GET'])
+        async def get_all_static_file(name: str) -> Response:
+            file_path = self.static_file_cacher.find_file_path(name)
+            if not file_path:
+                return Response('')
+            response = await send_file(file_path)
+            return response
+
     # pylint: disable=R1711
     @staticmethod
     def _load_plugin_from_local_file(plugin_path: str) -> Optional[WechatyPlugin]:
@@ -592,6 +736,10 @@ class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pyli
                 return
             plugin_instance = plugin
 
+        # set the scheduler
+        self.static_file_cacher.add_dir(plugin_instance.cache_dir)
+
+        plugin_instance.scheduler = self.scheduler
         self._plugins[plugin_instance.name] = plugin_instance
         # default wechaty plugin status is Running
         self._plugin_status[plugin_instance.name] = PluginStatus.Running
@@ -599,6 +747,15 @@ class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pyli
         # TODO(wj-Mcat): disable this event hook
         # await plugin_instance.on_loaded()
 
+    def plugins(self) -> Iterable[WechatyPlugin]:
+        """get all of registered plugins
+
+        Returns:
+            List[WechatyPlugin]: the list of wechaty plugins
+        """
+        for plugin in self._plugins.values():
+            yield plugin
+
     def remove_plugin(self, name: str) -> None:
         """remove plugin"""
         if name not in self._plugins:
@@ -664,6 +821,7 @@ class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pyli
             plugin.set_bot(self._wechaty)
             await plugin.init_plugin(self._wechaty)
             await plugin.blueprint(self.app)
+        self.scheduler.start()
         # check the host & port configuration
 
         # pylint: disable=W0212
@@ -676,21 +834,25 @@ class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pyli
         # 3. list all valid endpoints in web service
         # checking the number of registered blueprints
         routes_txt = _list_routes_txt(self.app)
-        # if len(routes_txt) == 0:
-        #     log.warning(
-        #         'there is not registed blueprint in the plugins, '
-    #         'so bot will not start the web service'
-        #     )
-        #     return
+        if len(routes_txt) == 0:
+            log.warning(
+                'there is not registed blueprint in the plugins, '
+                'so bot will not start the web service'
+            )
+            return
 
-        log.info('============================starting web service========================')
+        await self.register_ui_view(self.app)
+        # re-fetch the routes info
+        routes_txt = _list_routes_txt(self.app)
+
+        log.info(
+            '============================starting web service========================')
         log.info('starting web service at endpoint: <{%s}:{%d}>', host, port)
 
         shutdown_trigger = await get_shutdown_trigger()
         task = self.app.run_task(
             host=host,
             port=port,
-            use_reloader=False,
             shutdown_trigger=shutdown_trigger
         )
         loop = asyncio.get_event_loop()
@@ -703,7 +865,8 @@ class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pyli
         for route_txt in routes_txt:
             log.info(route_txt)
 
-        log.info('============================web service has started========================')
+        log.info(
+            '============================web service has started========================')
 
     # pylint: disable=too-many-locals,too-many-statements,too-many-branches
     async def emit_events(self, event_name: str, *args: Any, **kwargs: Any) -> None:
