@@ -25,7 +25,6 @@ from __future__ import annotations
 
 import asyncio
 import logging
-import sys
 import traceback
 from datetime import datetime
 from dataclasses import dataclass
@@ -33,14 +32,12 @@ from typing import (
     # TYPE_CHECKING,
     Any,
     Callable,
-    Coroutine,
     Optional,
     Type,
     List,
     Union,
     cast,
 )
-import signal
 
 import requests.exceptions
 from grpclib.exceptions import StreamTerminatedError
@@ -110,32 +107,6 @@ DEFAULT_TIMEOUT = 300
 PuppetModuleName = str
 
 
-async def get_shutdown_trigger() -> Callable[[], Coroutine[Any, Any, Any]]:
-    """register the system shutdown trigger event"""
-    signal_event = asyncio.Event()
-    loop = asyncio.get_event_loop()
-
-    def _signal_handler(*_: Any) -> None:  # noqa: N803
-        print('receive signal event ...')
-        signal_event.set()
-
-    for signal_name in ["SIGINT", "SIGTERM", "SIGBREAK"]:
-        if hasattr(signal, signal_name):
-            try:
-                loop.add_signal_handler(getattr(signal, signal_name), _signal_handler)
-            except NotImplementedError:
-                # Add signal handler may not be implemented on Windows
-                signal.signal(getattr(signal, signal_name), _signal_handler)
-
-    return signal_event.wait
-
-
-async def shutdown(trigger: Callable[[], Coroutine[Any, Any, Any]]) -> None:
-    """when trigger the shutdown, it will call sys.exit"""
-    await trigger()
-    sys.exit(0)
-
-
 # pylint: disable=too-many-instance-attributes
 @dataclass
 class WechatyOptions:
@@ -159,7 +130,11 @@ class WechatyOptions:
 # pylint:disable=R0902,R0904
 class Wechaty(AsyncIOEventEmitter):
     """
-    docstring
+    A robot is a Wechaty instance, \
+    and all user-related modules should be accessed through the instance, \
+    which ensures consistency of service connections. \
+    In addition, all logic should be organized in the form of plug-ins and \
+    event subscriptions to ensure isolation between different businesses.
     """
 
     _global_instance: Optional['Wechaty'] = None
@@ -171,7 +146,12 @@ class Wechaty(AsyncIOEventEmitter):
 
     def __init__(self, options: Optional[WechatyOptions] = None):
         """
-        docstring
+        init Wechaty instance
+        Args:
+            options: WechatyOptions
+        Examples:
+            >>> from wechaty import Wechaty
+            >>> bot = Wechaty()
         """
         super().__init__()
 
@@ -227,7 +207,10 @@ class Wechaty(AsyncIOEventEmitter):
     def puppet(self) -> Puppet:
         """
         Always expected to return a non-null puppet instance, or raise an error.
-        :return:
+        Args:
+            None
+        Returns:
+            Puppet: puppet instance
         """
         if not self._puppet:
             raise WechatyStatusError('Wechaty puppet not loaded!')
@@ -237,8 +220,10 @@ class Wechaty(AsyncIOEventEmitter):
     def _load_puppet(options: WechatyOptions) -> Puppet:
         """
         dynamic load puppet
-        :param options:
-        :return:
+        Args:
+            options: WechatyOptions
+        Returns:
+            Puppet: puppet instance
         """
         if options.puppet is None:
             raise WechatyConfigurationError('puppet not exist')
@@ -277,8 +262,11 @@ class Wechaty(AsyncIOEventEmitter):
     def instance(cls: Type[Wechaty], options: Optional[WechatyOptions] = None
                  ) -> Wechaty:
         """
-        get or create global wechaty instance
-        :return:
+        get or create global wechaty instance.
+        Args:
+            options: WechatyOptions
+        Returns:
+            Wechaty: global wechaty instance
         """
         log.info('instance()')
 
@@ -291,7 +279,12 @@ class Wechaty(AsyncIOEventEmitter):
         # return cls._global_instance
 
     def use(self, plugin: Union[WechatyPlugin, List[WechatyPlugin]]) -> Wechaty:
-        """register the plugin"""
+        """register the plugin
+        Args:
+            plugin: WechatyPlugin or List[WechatyPlugin]
+        Returns:
+            Wechaty: self
+        """
         if isinstance(plugin, WechatyPlugin):
             plugins = [plugin]
         else:
@@ -310,9 +303,15 @@ class Wechaty(AsyncIOEventEmitter):
     def on(self, event: str, f: Callable[..., Any] = None) -> Wechaty:
         """
         listen wechaty event
-        :param event:
-        :param f:
-        :return:
+        Args:
+            event: the event name, see at `WechatyEventName`.
+            listener: the function bind to event name, see at `WechatyEventFunction`.
+        Examples:
+            Event:scan
+            >>> bot.on('scan', lambda qrcode, status: print(qrcode, status))
+            >>> bot.start()
+        Returns:
+            Wechaty: self
         """
         log.info('on() listen event <%s> with <%s>', event, f)
         super().on(event, f)
@@ -321,10 +320,10 @@ class Wechaty(AsyncIOEventEmitter):
     def emit(self, event: str, *args: Any, **kwargs: Any) -> bool:
         """
         emit wechaty event
-        :param event:
-        :param args:
-        :param kwargs:
-        :return:
+        Args:
+            event: the event name need to emit, see at `WechatyEventName`.
+        Returns:
+            bool: True if emit success, False if emit failed.
         """
         log.debug('emit() event <%s> <%s>',
                   [str(item) for item in args],
@@ -424,7 +423,14 @@ class Wechaty(AsyncIOEventEmitter):
     async def start(self) -> None:
         """
         start wechaty bot
-        :return:
+        Args:
+            None
+        Examples:
+            >>> from wechaty import Wechaty
+            >>> bot = Wechaty()
+            >>> await bot.start()
+        Returns:
+            None
         """
 
         # If the network is shut-down, we should catch the connection
@@ -469,7 +475,17 @@ I suggest that you should follow the template code from: https://wechaty.readthe
             print(e)
 
     async def restart(self) -> None:
-        """restart the wechaty bot"""
+        """
+        restart the wechaty bot
+        Args:
+            None
+        Examples:
+            >>> from wechaty import Wechaty
+            >>> bot = Wechaty()
+            >>> await bot.restart()
+        Returns:
+            None
+        """
         log.info('restarting the bot ...')
         await self.stop()
         await self.start()
@@ -769,8 +785,8 @@ I suggest that you should follow the template code from: https://wechaty.readthe
 
         # Using metaclass to create a dynamic subclass to server multi bot instances.
         meta_info = dict(_puppet=self.puppet, _wechaty=self, abstract=False)
-        self.Contact = type('Contact', (Contact,), meta_info)
         self.ContactSelf = type('ContactSelf', (ContactSelf,), meta_info)
+        self.Contact = type('Contact', (Contact,), meta_info)
         self.Favorite = type('Favorite', (Favorite,), meta_info)
         self.Friendship = type('Friendship', (Friendship,), meta_info)
         self.Image = type('Image', (Image,), meta_info)
@@ -783,7 +799,13 @@ I suggest that you should follow the template code from: https://wechaty.readthe
 
     async def stop(self) -> None:
         """
-        stop the wechaty
+        stop the wechaty bot
+        Args:
+            None
+        Examples:
+            >>> await bot.stop()
+        Returns:
+            None
         """
         log.info('wechaty is stopping ...')
         await self.puppet.stop()
@@ -795,7 +817,14 @@ I suggest that you should follow the template code from: https://wechaty.readthe
     def user_self(self) -> ContactSelf:
         """
         get user self
-        :return:
+        Args:
+            None
+        Examples:
+            >>> from wechaty import Wechaty
+            >>> bot = Wechaty()
+            >>> contact = bot.user_self()
+        Returns:
+            ContactSelf: user self
         """
         user_id = self.puppet.self_id()
         user = self.ContactSelf.load(user_id)
@@ -806,6 +835,13 @@ I suggest that you should follow the template code from: https://wechaty.readthe
     def self(self) -> ContactSelf:
         """
         get user self
-        :return: user_self
+        Args:
+            None
+        Examples:
+            >>> from wechaty import Wechaty
+            >>> bot = Wechaty()
+            >>> contact = bot.self()
+        Returns:
+            ContactSelf: user self
         """
         return self.user_self()
